@@ -110,6 +110,12 @@ mod tests {
             { "gamma": 3, "delta": "something" },
             { "alpha": 7 },
             { "delta": 4 }  
+        ],
+        "lenses-filter": [
+            { "alpha": 1, "shared": "a" },
+            { "beta": 2, "shared": "b" },
+            { "gamma": 3, "shared": "c" },
+            { "delta": 4, "shared": "d" }  
         ]
     }"#;
 
@@ -815,7 +821,8 @@ mod tests {
                 "nested-filter": [],
                 "filter-to-flatten": [],
                 "nested-filter-to-flatten": [],
-                "lenses": []
+                "lenses": [],
+                "lenses-filter": []
             })),
             walker(&json, selector)
         );
@@ -899,4 +906,11 @@ mod tests {
             walker(&json, selector_key_value_multiple)
         );
     }
+
+    #[test]
+    fn check_lens_with_filter() {
+        let json: Value = serde_json::from_str(DATA).unwrap();
+        let selector = r#""lenses-filter"|={"delta","alpha"}|"shared""#;
+        assert_eq!(Ok(json!(["a", "d"])), walker(&json, selector));
+    }
 }
