@@ -12,6 +12,7 @@ use serde_json::{json, Value};
 pub fn group_walker(
     Group {
         filters,
+        filter_lenses,
         root,
         selectors,
         spread,
@@ -36,7 +37,7 @@ pub fn group_walker(
 
             let is_spreading = spread.is_some();
 
-            let output = match apply_filter(filters, &output_json) {
+            let output = match apply_filter(filters, filter_lenses, &output_json) {
                 Ok(filtered) => match filtered {
                     MaybeArray::Array(array) => Ok(if is_spreading {
                         flatten_json_array(&json!(array))
