@@ -79,12 +79,13 @@ fn span_to_object_range(pair: PestPair<'_>) -> InnerObject {
 }
 
 /// Return a vector of chars found inside a default pair.
-fn get_chars_from_default_pair(pair: PestPair<'_>) -> Vec<String> {
+fn get_chars_from_pair(pair: PestPair<'_>) -> Vec<String> {
     pair.into_inner()
         .fold(Vec::new(), |mut acc: Vec<String>, inner_pair| {
             if inner_pair.as_rule() == Rule::chars {
                 acc.push(String::from(inner_pair.clone().as_span().as_str()));
             }
+
             acc
         })
 }
@@ -95,10 +96,30 @@ fn get_inner_object_from_pair(pair: PestPair<'_>) -> Vec<InnerObject> {
         .fold(Vec::new(), |mut acc: Vec<InnerObject>, inner_pair| {
             match inner_pair.as_rule() {
                 Rule::default => {
-                    acc.push(InnerObject::Key(
-                        get_chars_from_default_pair(inner_pair)[0].clone(),
+                    acc.push(InnerObject::KeyValue(
+                        get_chars_from_pair(inner_pair)[0].clone(),
+                        None,
                     ));
                 }
+                Rule::filter_lens_key_value_pair => {
+                    let key = &get_chars_from_pair(
+                        inner_pair
+                            .clone()
+                            .into_inner()
+                            .into_iter()
+                            .next()
+                            .unwrap()
+                            .into_inner()
+                            .next()
+                            .unwrap(),
+                    )[0];
+
+                    let maybe_value = inner_pair.into_inner().into_iter().nth(1).map(|pair| {
+                        get_chars_from_pair(pair.into_inner().next().unwrap())[0].clone()
+                    });
+
+                    acc.push(InnerObject::KeyValue(key.to_string(), maybe_value));
+                }
                 Rule::object_range => {
                     acc.push(span_to_object_range(
                         inner_pair.into_inner().next().unwrap(),
@@ -132,22 +153,24 @@ pub fn selectors_parser(selectors: &str) -> Result<Vec<Group>, String> {
                     // parser.
                     match inner_pair.as_rule() {
                         // Default
-                        Rule::default => group.selectors.push(span_to_default(
-                            &get_chars_from_default_pair(inner_pair)[0].clone(),
-                        )),
+                        Rule::default => group
+                            .selectors
+                            .push(span_to_default(&get_chars_from_pair(inner_pair)[0].clone())),
                         Rule::filter_default => group.filters.push(span_to_default(
-                            &get_chars_from_default_pair(inner_pair.into_inner().next().unwrap())
-                                [0]
-                            .clone(),
+                            &get_chars_from_pair(inner_pair.into_inner().next().unwrap())[0]
+                                .clone(),
                         )),
+
                         // Index
                         Rule::index => group.selectors.push(span_to_index(inner_span)),
                         Rule::filter_index => group.filters.push(span_to_index(inner_span)),
+
                         // Range
                         Rule::range => group.selectors.push(span_to_range(inner_pair)),
                         Rule::filter_range => group
                             .filters
                             .push(span_to_range(inner_pair.into_inner().next().unwrap())),
+
                         // Property
                         Rule::property => group
                             .selectors
@@ -155,10 +178,18 @@ pub fn selectors_parser(selectors: &str) -> Result<Vec<Group>, String> {
                         Rule::filter_property => group
                             .filters
                             .push(Selector::Object(get_inner_object_from_pair(inner_pair))),
+
+                        // Filter lenses property.
+                        Rule::filter_lens_key_value => group
+                            .filter_lenses
+                            .push(Selector::Object(get_inner_object_from_pair(inner_pair))),
+
                         // Root
                         Rule::root => group.root = Some(()),
+
                         // Spread
                         Rule::spread => group.spread = Some(()),
+
                         // Truncate
                         Rule::truncate => group.truncate = Some(()),
                         _ => (),
